@@ -34,7 +34,7 @@ sub new {
 			$this->{pydef} = `pyversions -vd 2>/dev/null`;}
 		$this->{pydef} =~ s/\s+$//;
 		if ($ENV{'DEBPYTHON_SUPPORTED'}) {
-			$this->{pyvers} = $ENV{'DEBPYTHON_SUPPORTED'};}
+			$this->{pyvers} = $ENV{'DEBPYTHON_SUPPORTED'} =~ s/,/ /r;}
 		else {
 			$this->{pyvers} = `pyversions -vr 2>/dev/null`;}
 		$this->{pyvers} =~ s/\s+$//;
@@ -44,9 +44,15 @@ sub new {
 			$this->{py3def} = `py3versions -vd 2>/dev/null`;}
 		$this->{py3def} =~ s/\s+$//;
 		if ($ENV{'DEBPYTHON3_SUPPORTED'}) {
-			$this->{py3vers} = $ENV{'DEBPYTHON3_SUPPORTED'};}
+			$this->{py3vers} = $ENV{'DEBPYTHON3_SUPPORTED'} =~ s/,/ /r;}
 		else {
-			$this->{py3vers} = `py3versions -vr 2>/dev/null`;}
+			$this->{py3vers} = `py3versions -vr 2>/dev/null`;
+			if ($this->{py3vers} eq "") {
+				# We swallowed stderr, above
+				system("py3versions -vr");
+				die('E: py3versions failed');
+			}
+		}
 		$this->{py3vers} =~ s/\s+$//;
 		$this->{pypydef} = `pypy -c 'from sys import pypy_version_info as i; print("%s.%s" % (i.major, i.minor))' 2>/dev/null`;
 		$this->{pypydef} =~ s/\s+$//;
@@ -151,10 +157,10 @@ sub pybuild_commands {
 		my @pypyopts = ('pybuild', "--$step");
 
 		if ($step eq 'test' and $ENV{'PYBUILD_TEST_PYTEST'} ne '1' and
-		       			$ENV{'PYBUILD_TEST_NOSE2'} ne '1' and
-		       			$ENV{'PYBUILD_TEST_NOSE'} ne '1' and
-		       			$ENV{'PYBUILD_TEST_CUSTOM'} ne '1' and
-		       			$ENV{'PYBUILD_TEST_TOX'} ne '1') {
+				$ENV{'PYBUILD_TEST_NOSE2'} ne '1' and
+				$ENV{'PYBUILD_TEST_NOSE'} ne '1' and
+				$ENV{'PYBUILD_TEST_CUSTOM'} ne '1' and
+				$ENV{'PYBUILD_TEST_TOX'} ne '1') {
 			if (grep {$_ eq 'python-tox'} @deps and $ENV{'PYBUILD_TEST_TOX'} ne '0') {
 				push @py2opts, '--test-tox'}
 			elsif (grep {$_ eq 'python-pytest'} @deps and $ENV{'PYBUILD_TEST_PYTEST'} ne '0') {
@@ -199,7 +205,7 @@ sub pybuild_commands {
 		}
 		if ($this->{pydef}) {
 			if (not $pyall and grep {$_ eq 'python' or $_ eq 'python-dev' or
-				       		 $_ eq 'python2.7' or $_ eq 'python2.7-dev'} @deps) {
+					$_ eq 'python2.7' or $_ eq 'python2.7-dev'} @deps) {
 				push @result, [@py2opts, '-i', $i, '-p', $this->{pydef}, @options];
 			}
 			if (not $pyalldbg and grep {$_ eq 'python-dbg' or $_ eq 'python2.7-dbg'} @deps) {
